# gaftools

gaftools is a fast and comprehensive toolkit designed for processing pangenome alignments. It provides various functionalities such as indexing, sorting, realignment, viewing and statistical analysis of rGFA-based GAF files.

Detailed documentation is available [here](https://gaftools.readthedocs.io/en/latest/index.html).

The preprint is available [here](https://www.biorxiv.org/content/10.1101/2024.12.10.627813v1).

## Citation

Pani, S., Dabbaghie, F., Marschall, T. & Söylev, A. gaftools: a toolkit for analyzing and manipulating pangenome alignments. (2024) doi:10.1101/2024.12.10.627813.
